==> hadoop-client-api-3.3.1-sources.jar: org/apache/hadoop/yarn/server/api/protocolrecords/RefreshServiceAclsRequest.java <==
/**
* Licensed to the Apache Software Foundation (ASF) under one
* or more contributor license agreements.  See the NOTICE file
* distributed with this work for additional information
* regarding copyright ownership.  The ASF licenses this file
* to you under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in org.apache.hadoop.shaded.com.liance
* with the License.  You may obtain a copy of the License at
*
*     http://www.apache.org.apache.hadoop.shaded.org.licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package org.apache.hadoop.shaded.org.apache.hadoop.yarn.server.api.protocolrecords;

import org.apache.hadoop.shaded.org.apache.hadoop.classification.InterfaceAudience.Private;
import org.apache.hadoop.shaded.org.apache.hadoop.classification.InterfaceAudience.Public;
import org.apache.hadoop.shaded.org.apache.hadoop.classification.InterfaceStability.Stable;
import org.apache.hadoop.shaded.org.apache.hadoop.yarn.util.Records;

@Private
@Stable
public abstract class RefreshServiceAclsRequest {
  @Public
  @Stable
  public static RefreshServiceAclsRequest newInstance() {
    RefreshServiceAclsRequest request =
        Records.newRecord(RefreshServiceAclsRequest.class);
    return request;
  }
}

==> hadoop-client-api-3.4.0-sources.jar: org/apache/hadoop/yarn/server/api/protocolrecords/RefreshServiceAclsRequest.java <==
/**
* Licensed to the Apache Software Foundation (ASF) under one
* or more contributor license agreements.  See the NOTICE file
* distributed with this work for additional information
* regarding copyright ownership.  The ASF licenses this file
* to you under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance
* with the License.  You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package org.apache.hadoop.shaded.org.apache.hadoop.yarn.server.api.protocolrecords;

import org.apache.hadoop.shaded.org.apache.hadoop.classification.InterfaceAudience.Private;
import org.apache.hadoop.shaded.org.apache.hadoop.classification.InterfaceAudience.Public;
import org.apache.hadoop.shaded.org.apache.hadoop.classification.InterfaceStability.Stable;
import org.apache.hadoop.shaded.org.apache.hadoop.yarn.util.Records;

@Private
@Stable
public abstract class RefreshServiceAclsRequest {
  @Public
  @Stable
  public static RefreshServiceAclsRequest newInstance() {
    RefreshServiceAclsRequest request =
        Records.newRecord(RefreshServiceAclsRequest.class);
    return request;
  }

  @Public
  @Stable
  public static RefreshServiceAclsRequest newInstance(String subClusterId) {
    RefreshServiceAclsRequest request =
        Records.newRecord(RefreshServiceAclsRequest.class);
    request.setSubClusterId(subClusterId);
    return request;
  }

  /**
   * Get the subClusterId.
   *
   * @return subClusterId.
   */
  public abstract String getSubClusterId();

  /**
   * Set the subClusterId.
   *
   * @param subClusterId subCluster Id.
   */
  public abstract void setSubClusterId(String subClusterId);
}
